@@ -28,8 +28,9 @@ def resolve_literalinclude_path(
     if _include_path.exists():
         return str(_include_path.resolve())
 
+    _base_dir = Path(base_dir.dirname) if base_dir.isfile() else base_dir
     try:
-        full_path = base_dir / include_path
+        full_path = _base_dir / include_path
         if full_path.exists():
             return str(full_path.resolve())
     except Exception:
